#ifndef nrnoc2iv_h
#define nrnoc2iv_h
// common things in nrnoc that can be used by nrniv

#include "oc2iv.h"

#include "section.h"

#include "ndatclas.h"

#endif
